summaryrefslogtreecommitdiffstats
path: root/src/flowlayout.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:30:39 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:30:39 -0600
commit6981c239dedc72969f6f539afeef646a19c867c0 (patch)
tree44e5e93a8ed355a26920da44467d4b18be8fcc05 /src/flowlayout.cpp
parentdfe4a152e1587751bbb3e63e46c4d727e318caaf (diff)
downloadkima-6981c239dedc72969f6f539afeef646a19c867c0.tar.gz
kima-6981c239dedc72969f6f539afeef646a19c867c0.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'src/flowlayout.cpp')
-rw-r--r--src/flowlayout.cpp50
1 files changed, 25 insertions, 25 deletions
diff --git a/src/flowlayout.cpp b/src/flowlayout.cpp
index 7f10faf..13490cf 100644
--- a/src/flowlayout.cpp
+++ b/src/flowlayout.cpp
@@ -156,7 +156,7 @@ bool FlowLayout::moveItem(const TQLayoutItem* which, const TQLayoutItem* relate,
newPos += direction;
// actually reinsert the item
mLayoutItems.insert(newPos, which);
- activate(); // retqlayout
+ activate(); // relayout
// kdDebug() << "oldPos: " << oldPos << ", newPos: " << newPos << endl;
return true;
}
@@ -181,25 +181,25 @@ bool FlowLayout::hasWidthForHeight() const{
return mOrientation == Qt::Horizontal;
}
-TQSize FlowLayout::tqsizeHint() const{
- //return tqminimumSize();
+TQSize FlowLayout::sizeHint() const{
+ //return minimumSize();
TQSize size(0,0);
TQPtrListIterator<TQLayoutItem> it(mLayoutItems);
TQLayoutItem *o;
while((o=it.current()) != 0){
++it;
- size = size.expandedTo( o->tqsizeHint() );
+ size = size.expandedTo( o->sizeHint() );
}
return size;
}
-TQSize FlowLayout::tqminimumSize() const{
+TQSize FlowLayout::minimumSize() const{
TQSize size(0,0);
TQPtrListIterator<TQLayoutItem> it(mLayoutItems);
TQLayoutItem *o;
while((o=it.current()) != 0){
++it;
- size = size.expandedTo(o->tqminimumSize());
+ size = size.expandedTo(o->minimumSize());
}
return size;
}
@@ -250,32 +250,32 @@ int FlowLayout::doLayoutHorizontal( const TQRect& rect, bool testOnly ){
TQPtrList<TQLayoutItem> column; // stores the items of one column
while((layoutItem = it.current()) != 0){
++it;
- //int nextY = y + layoutItem->tqsizeHint().height() + spacing(); // next y
- int nextY = y + layoutItem->tqsizeHint().height(); // next y
+ //int nextY = y + layoutItem->sizeHint().height() + spacing(); // next y
+ int nextY = y + layoutItem->sizeHint().height(); // next y
//if( nextY - spacing() > rect.bottom() && width > 0 ) {
if( nextY > rect.bottom() && width > 0 ) {
// next column
y = rect.y(); // reset y
x = x + width + spacing(); // new x
- //nextY = y + layoutItem->tqsizeHint().height() + spacing(); // next y with changed y
- nextY = y + layoutItem->tqsizeHint().height(); // next y with changed y
+ //nextY = y + layoutItem->sizeHint().height() + spacing(); // next y with changed y
+ nextY = y + layoutItem->sizeHint().height(); // next y with changed y
width = 0; // reset width for the next column
}
if(!testOnly){
- layoutItem->setGeometry( TQRect( TQPoint( x, y ), layoutItem->tqsizeHint() ) );
+ layoutItem->setGeometry( TQRect( TQPoint( x, y ), layoutItem->sizeHint() ) );
column.append(layoutItem);
- height += layoutItem->tqsizeHint().height(); // add the height of the current item to the column height
- if( it.current() == 0 || nextY + it.current()->tqsizeHint().height() > rect.bottom() ){ // test it it's the last item (of this column)
+ height += layoutItem->sizeHint().height(); // add the height of the current item to the column height
+ if( it.current() == 0 || nextY + it.current()->sizeHint().height() > rect.bottom() ){ // test it it's the last item (of this column)
// calculate real needed width
int rWidth = 0;
for(TQLayoutItem* item = column.first(); item; item = column.next()){
- rWidth = TQMAX( rWidth, item->widget()->tqsizeHint().width() );
+ rWidth = TQMAX( rWidth, item->widget()->sizeHint().width() );
}
- // retqlayout the items of the former column
+ // relayout the items of the former column
int space = (rect.height() - height) / (column.count() + 1);
int i = 0; // counts the items of this column
for(TQLayoutItem* item = column.first(); item; item = column.next()){
- TQRect r = item->tqgeometry();
+ TQRect r = item->geometry();
item->setGeometry( TQRect(r.left(), r.top() + ((++i) * space), rWidth, r.height()) );
}
column.clear(); // remove the items of the former column
@@ -283,7 +283,7 @@ int FlowLayout::doLayoutHorizontal( const TQRect& rect, bool testOnly ){
}
}
y = nextY;
- width = TQMAX( width, layoutItem->tqsizeHint().width() );
+ width = TQMAX( width, layoutItem->sizeHint().width() );
}
return x + width - rect.x(); // width
}
@@ -296,18 +296,18 @@ int FlowLayout::doLayoutVertical( const TQRect& rect, bool testOnly ){
TQLayoutItem* layoutItem;
while((layoutItem = it.current() ) != 0){
++it;
- //int nextX = x + layoutItem->tqsizeHint().width() + spacing();
- int nextX = x + layoutItem->tqsizeHint().width();
+ //int nextX = x + layoutItem->sizeHint().width() + spacing();
+ int nextX = x + layoutItem->sizeHint().width();
if(nextX - spacing() > rect.right() && height > 0) {
// next line
x = rect.x(); // reset x
//y = y + height + spacing(); // new y
y = y + height; // new y
- //nextX = x + layoutItem->tqsizeHint().width() + spacing(); // next x
- nextX = x + layoutItem->tqsizeHint().width(); // next x
+ //nextX = x + layoutItem->sizeHint().width() + spacing(); // next x
+ nextX = x + layoutItem->sizeHint().width(); // next x
height = 0; // reset height for the next line
}
- const int itemHeight = layoutItem->tqsizeHint().height();
+ const int itemHeight = layoutItem->sizeHint().height();
if(!testOnly)
layoutItem->setGeometry(TQRect(x, y, rect.right(), itemHeight));
x = nextX;
@@ -328,7 +328,7 @@ int FlowLayout::count() const {
\reimp
*/
TQLayoutItem* FlowLayout::itemAt(int index) const {
- return index >= 0 && index < mLayoutItems.count() ? (const_cast<TQPtrList<TQLayoutItem>&>(mLayoutItems).tqat(index)) : 0;
+ return index >= 0 && index < mLayoutItems.count() ? (const_cast<TQPtrList<TQLayoutItem>&>(mLayoutItems).at(index)) : 0;
}
/*!
@@ -337,8 +337,8 @@ TQLayoutItem* FlowLayout::itemAt(int index) const {
TQLayoutItem* FlowLayout::takeAt(int index) {
if (index < 0 || index >= mLayoutItems.count())
return 0;
- TQLayoutItem *item = mLayoutItems.tqat(index);
- mLayoutItems.remove(mLayoutItems.tqat(index));
+ TQLayoutItem *item = mLayoutItems.at(index);
+ mLayoutItems.remove(mLayoutItems.at(index));
delete item;
invalidate();